@@ -20,13 +20,14 @@ from numpy.testing import (assert_array_equal, assert_array_almost_equal,
 import warnings
 
 from .. import data, io
+from ..data._fetchers import _fetch
 from ..util import img_as_uint, img_as_float, img_as_int, img_as_ubyte
-import pytest
 from ._warnings import expected_warnings
 
 
 SKIP_RE = re.compile(r"(\s*>>>.*?)(\s*)#\s*skip\s+if\s+(.*)$")
 
+import pytest
 skipif = pytest.mark.skipif
 xfail = pytest.mark.xfail
 parametrize = pytest.mark.parametrize
@@ -39,6 +40,17 @@ fixture = pytest.fixture
 arch32 = struct.calcsize("P") * 8 == 32
 
 
+_error_on_warnings = os.environ.get('SKIMAGE_TEST_STRICT_WARNINGS_GLOBAL', '0')
+if _error_on_warnings.lower() == 'true':
+    _error_on_warnings = True
+elif _error_on_warnings.lower() == 'false':
+    _error_on_warnings = False
+else:
+    try:
+        _error_on_warnings = bool(int(_error_on_warnings))
+    except ValueError:
+        _error_on_warnings = False
+
 def assert_less(a, b, msg=None):
     message = "%r is not lower than %r" % (a, b)
     if msg is not None:
@@ -193,13 +205,79 @@ def setup_test():
     """
     warnings.simplefilter('default')
 
-    from scipy import signal, ndimage, special, optimize, linalg
-    from scipy.io import loadmat
-    from skimage import viewer
+    if _error_on_warnings:
+        from scipy import signal, ndimage, special, optimize, linalg
+        from scipy.io import loadmat
+        from skimage import viewer
 
-    np.random.seed(0)
+        np.random.seed(0)
 
-    warnings.simplefilter('error')
+        warnings.simplefilter('error')
+
+        # do not error on specific warnings from the skimage.io module
+        # https://github.com/scikit-image/scikit-image/issues/5337
+        warnings.filterwarnings(
+            'default', message='TiffFile:', category=DeprecationWarning
+        )
+
+        warnings.filterwarnings(
+            'default', message='TiffWriter:', category=DeprecationWarning
+        )
+        # newer tifffile change the start of the warning string
+        # e.g. <tifffile.TiffWriter.write> data with shape ...
+        warnings.filterwarnings(
+            'default',
+            message='<tifffile.',
+            category=DeprecationWarning
+        )
+
+        warnings.filterwarnings(
+            'default', message='unclosed file', category=ResourceWarning
+        )
+
+        # ignore known FutureWarnings from viewer module
+        warnings.filterwarnings(
+            'ignore', category=FutureWarning, module='skimage.viewer'
+        )
+
+        # Ignore other warnings only seen when using older versions of
+        # dependencies.
+        warnings.filterwarnings(
+            'default',
+            message='Conversion of the second argument of issubdtype',
+            category=FutureWarning
+        )
+
+        warnings.filterwarnings(
+            'default',
+            message='the matrix subclass is not the recommended way',
+            category=PendingDeprecationWarning, module='numpy'
+        )
+
+        warnings.filterwarnings(
+            'default',
+            message='Your installed pillow version',
+            category=UserWarning,
+            module='skimage.io'
+        )
+
+        # match both "Viewer requires Qt" and "Viewer requires matplotlib"
+        warnings.filterwarnings(
+            'default', message='Viewer requires ', category=UserWarning
+        )
+
+        # ignore warning from cycle_spin about Dask not being installed
+        warnings.filterwarnings(
+            'default',
+            message='The optional dask dependency is not installed.',
+            category=UserWarning
+        )
+
+        warnings.filterwarnings(
+            'default',
+            message='numpy.ufunc size changed',
+            category=RuntimeWarning
+        )
 
 
 def teardown_test():
@@ -207,15 +285,18 @@ def teardown_test():
 
     Restore warnings to default behavior
     """
-    warnings.simplefilter('default')
+    if _error_on_warnings:
+        warnings.resetwarnings()
+        warnings.simplefilter('default')
 
 
 def fetch(data_filename):
     """Attempt to fetch data, but if unavailable, skip the tests."""
     try:
-        return data._fetch(data_filename)
-    except ConnectionError:
-        pytest.skip(f'Unable to download {data_filename}')
+        return _fetch(data_filename)
+    except (ConnectionError, ModuleNotFoundError):
+        pytest.skip(f'Unable to download {data_filename}',
+                    allow_module_level=True)
 
 
 def test_parallel(num_threads=2, warnings_matching=None):
