@@ -5,11 +5,12 @@ __getattr__, __dir__, __all__ = lazy.attach(
     submodules={},
     submod_attrs={
         '_binary_blobs': ['binary_blobs'],
-        '_fetchers': ['data_dir', 'download_all', 'astronaut', 'binary_blobs',
-                      'brain', 'brick', 'camera', 'cat', 'cell', 'cells3d',
-                      'checkerboard', 'chelsea', 'clock', 'coffee', 'coins',
-                      'colorwheel', 'eagle', 'grass', 'gravel', 'horse',
-                      'hubble_deep_field', 'human_mitosis',
+        '_fetchers': ['create_image_fetcher', 'data_dir', 'download_all',
+                      'file_hash', 'image_fetcher', 'astronaut',
+                      'binary_blobs', 'brain', 'brick', 'camera', 'cat',
+                      'cell', 'cells3d', 'checkerboard', 'chelsea', 'clock',
+                      'coffee', 'coins', 'colorwheel', 'eagle', 'grass',
+                      'gravel', 'horse', 'hubble_deep_field', 'human_mitosis',
                       'immunohistochemistry', 'kidney',
                       'lbp_frontal_face_cascade_filename', 'lily',
                       'lfw_subset', 'logo', 'microaneurysms', 'moon', 'page',
